==> indy-node-dev-1.0.88.tar.gz: indy-node-dev-1.0.88/sovrin_client/test/agent/helper.py <==
import argparse
import sys

from sovrin_client.agent.helper import buildAgentWallet
from sovrin_client.test import waits
from stp_core.loop.eventually import eventually
from sovrin_client.agent.run_agent import runAgent
from sovrin_common.config_util import getConfig

config = getConfig()


def connectAgents(agent1, agent2):
    e1 = agent1.endpoint
    e2 = agent2.endpoint
    e1.connectTo(e2.ha)


def ensureAgentConnected(looper, agent, link):
    linkHa = link.getRemoteEndpoint(required=True)
    def _checkConnected():
        assert agent.endpoint.isConnectedTo(ha=linkHa)

    timeout = waits.expectedAgentConnected()
    looper.run(eventually(_checkConnected, timeout=timeout))


def getAgentCmdLineParams():
    if sys.stdin.isatty():
        parser = argparse.ArgumentParser(
            description="Starts agents with given port, cred def and issuer seq")

        parser.add_argument('--port', required=False,
                            help='port where agent will listen')

        parser.add_argument('--withcli',
                            help='if given, agent will start in cli mode',
                            action='store_true')

        args = parser.parse_args()
        port = int(args.port) if args.port else None
        with_cli = args.withcli
        return port, with_cli
    else:
        return None, False


def buildFaberWallet():
    return buildAgentWallet("FaberCollege", b'Faber000000000000000000000000000')


def buildAcmeWallet():
    return buildAgentWallet("AcmeCorp", b'Acme0000000000000000000000000000')


def buildThriftWallet():
    return buildAgentWallet("ThriftBank", b'Thrift00000000000000000000000000')


def startAgent(looper, agent, wallet, bootstrap=None):
    agent = agent
    wallet.pendSyncRequests()
    prepared = wallet.preparePending()
    agent.client.submitReqs(*prepared)

    runAgent(agent, looper, bootstrap=bootstrap)
    return agent, wallet

==> indy-node-dev-1.1.114.tar.gz: indy-node-dev-1.1.114/sovrin_client/test/agent/helper.py <==
import argparse
import sys

from sovrin_client.agent.helper import buildAgentWallet
from sovrin_client.test import waits
from stp_core.loop.eventually import eventually
from sovrin_client.agent.run_agent import runAgent
from sovrin_common.config_util import getConfig

config = getConfig()


def connectAgents(agent1, agent2):
    e1 = agent1.endpoint
    e2 = agent2.endpoint
    e1.connectTo(e2.ha)


def ensureAgentConnected(looper, agent, link):
    linkHa = link.getRemoteEndpoint(required=True)

    def _checkConnected():
        assert agent.endpoint.isConnectedTo(ha=linkHa)

    timeout = waits.expectedAgentConnected()
    looper.run(eventually(_checkConnected, timeout=timeout))


def getAgentCmdLineParams():
    if sys.stdin.isatty():
        parser = argparse.ArgumentParser(
            description="Starts agents with given port, cred def and issuer seq")

        parser.add_argument('--port', required=False,
                            help='port where agent will listen')

        parser.add_argument('--withcli',
                            help='if given, agent will start in cli mode',
                            action='store_true')

        args = parser.parse_args()
        port = int(args.port) if args.port else None
        with_cli = args.withcli
        return port, with_cli
    else:
        return None, False


def buildFaberWallet():
    return buildAgentWallet(
        "FaberCollege", b'Faber000000000000000000000000000')


def buildAcmeWallet():
    return buildAgentWallet("AcmeCorp", b'Acme0000000000000000000000000000')


def buildThriftWallet():
    return buildAgentWallet("ThriftBank", b'Thrift00000000000000000000000000')


def startAgent(looper, agent, wallet, bootstrap=None):
    agent = agent
    wallet.pendSyncRequests()
    prepared = wallet.preparePending()
    agent.client.submitReqs(*prepared)

    runAgent(agent, looper, bootstrap=bootstrap)
    return agent, wallet
